# Generated by Django 2.2.20 on 2021-08-25 08:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("djangocms_faq", "0002_auto_20210531_1650"),
    ]

    def update_all_uuids_by_random_ones(apps, schema_editor):
        from collections import defaultdict
        import random
        import uuid

        from djangocms_faq.models import (
            FaqPluginModel,
            RelationSearchFaq,
            SearchFaqPluginModel,
        )

        print("\nUpdating faqs...")

        print("Listing all same uuids...")
        # get a list of lists of faqs sorted by same uuid
        # ex:
        # [
        #   ['aaaa-aaaa',
        #    'aaaa-aaaa',
        #    'aaaa-aaaa',
        #   ],
        #   ['bbbb-bbbb',
        #    'bbbb-bbbb',
        #   ]
        #   ...
        # ]
        faqs = FaqPluginModel.objects.order_by("uuid")
        faqs_dict = defaultdict(list)
        for faq in faqs:
            faqs_dict[faq.uuid].append(faq)
        faqs_sorted = list(faqs_dict.values())

        for faqs in faqs_sorted:
            # each group of faq with same uuid
            for faq in faqs:
                # reinit uuid for faq
                rd = random.Random()
                new_uuid = uuid.UUID(int=rd.getrandbits(128))
                faq.uuid = new_uuid
                faq.save()

        print("Done!\nUpdating searches & relations...")

        # same thing but for searches this time
        searches = SearchFaqPluginModel.objects.order_by("uuid")
        searches_dict = defaultdict(list)
        for search in searches:
            searches_dict[search.uuid].append(search)
        searches_sorted = list(searches_dict.values())

        for searches in searches_sorted:
            for search in searches:
                rd = random.Random()
                new_uuid = uuid.UUID(int=rd.getrandbits(128))
                search.uuid = new_uuid
                search.save()

                for faq in search.search_in.all():
                    # create relations between faqs and searchs
                    if not RelationSearchFaq.objects.filter(
                        search=search.uuid, faq=faq.uuid
                    ):
                        new_relation = RelationSearchFaq()
                        new_relation.faq = search.uuid
                        new_relation.search = faq.uuid
                        new_relation.save()

        print("Done!")

    operations = [
        migrations.RemoveField(
            model_name="faqpluginmodel",
            name="show_title",
        ),
        migrations.AddField(
            model_name="faqpluginmodel",
            name="name",
            field=models.CharField(
                default="No name",
                help_text="Required. Will not be displayed on the website. Used to distinguish between several faqs.<br />",
                max_length=300,
                verbose_name="Nom",
            ),
        ),
        migrations.AlterField(
            model_name="faqpluginmodel",
            name="title",
            field=models.CharField(
                blank=True,
                help_text="Optional. Title that will be displayed on top of the FAQ. If not specified, nothing will be displayed.",
                max_length=300,
                verbose_name="Titre",
            ),
        ),
        migrations.AlterField(
            model_name="questionfaqpluginmodel",
            name="slug",
            field=models.SlugField(
                blank=True,
                default="",
                help_text="Unique slug for this question. Keep empty to let it be auto-generated. <br /><i>Warning: There is no control that the slug is unique, so you have to update it yourself if there is another question on the same page with the same slug.</i>",
                max_length=300,
            ),
        ),
        migrations.AlterField(
            model_name="searchfaqpluginmodel",
            name="search_in",
            field=models.ManyToManyField(
                help_text="Format: name (source page name).<br />",
                limit_choices_to={"placeholder__page__publisher_is_draft": True},
                to="djangocms_faq.FaqPluginModel",
                verbose_name="Rechercher",
            ),
        ),
        migrations.RunPython(code=update_all_uuids_by_random_ones),
    ]



import uuid

from cms.models.pluginmodel import CMSPlugin
from django import template
from django.db import models
from django.utils.safestring import mark_safe
from django.utils.text import slugify
from django.utils.translation import activate, deactivate, ugettext as _


register = template.Library()


class FaqPluginModel(CMSPlugin):
    title = models.CharField(
        _("Title"),
        max_length=300,
        blank=True,
        help_text=_(
            "Optional. Title that will be displayed on top of the FAQ. If not specified, nothing will be displayed."
        ),
    )
    name = models.CharField(
        _("Name"),
        max_length=300,
        default="No name",
        help_text=_(
            "Required. Will not be displayed on the website. Used to distinguish between several faqs.<br />"
        ),
    )
    uuid = models.UUIDField(primary_key=False, editable=False, default=uuid.uuid4)

    def get_page_url(self):
        try:
            activate(self.language)
            # thx https://stackoverflow.com/a/47953774/6813732
            url = mark_safe(
                '<a href="'
                + self.placeholder.page.get_absolute_url()
                + '" target="_blank">'
                + self.placeholder.page.get_page_title()
                + "</a>"
            )
            deactivate()
            return url
        except AttributeError:
            return _("Not on a page (maybe an apphook, like the blog)")

    get_page_url.short_description = _("Page")

    class Meta:
        verbose_name = _("Faq Container")

    def __unicode__(self):
        try:
            return f"{self.name} ({self.placeholder.page})"
        except AttributeError:
            return f"{self.name} ({self.placeholder.page}) − " + _("Draft")

    def __str__(self):
        try:
            return f"{self.name} ({self.placeholder.page})"
        except AttributeError:
            return f"{self.name} ({self.placeholder.page}) - " + _("Draft")

    def copy_relations(self, oldinstance):
        for relation in RelationSearchFaq.objects.filter(faq=self.uuid):
            faq = SearchFaqPluginModel.objects.filter(uuid=relation.faq)
            faq.search_in.add(self)


class QuestionFaqPluginModel(CMSPlugin):
    question = models.CharField(_("Question"), max_length=300)
    keywords = models.ManyToManyField(
        "djangocms_faq.Keyword",
        verbose_name=_("Keywords"),
        help_text=_(
            'Keywords are not used for SEO purposes, but to allow visitors to find FAQ questions via synonyms. For example, for a question such as "Are pets allowed?", you could add the keyword "dog".'
        ),
        blank=True,
    )
    slug = models.SlugField(
        blank=True,
        default="",
        help_text=_(
            "Unique slug for this question. Keep empty to let it be auto-generated. <br /><i>Warning: There is no control that the slug is unique, so you have to update it yourself if there is another question on the same page with the same slug.</i>"
        ),
        max_length=300,
    )

    @property
    def get_full_url(self):
        try:
            return self.placeholder.page.get_absolute_url()
        except AttributeError:
            return ""

    def get_page_url(self):
        try:
            activate(self.language)
            # thx https://stackoverflow.com/a/47953774/6813732
            url = mark_safe(
                '<a href="'
                + self.placeholder.page.get_absolute_url()
                + '" target="_blank">'
                + self.placeholder.page.get_page_title()
                + "</a>"
            )
            deactivate()
            return url
        except AttributeError:
            return _("Not on a page (maybe an apphook, like the blog)")

    get_page_url.short_description = _("Page")

    def copy_relations(self, oldinstance):
        self.keywords.set(oldinstance.keywords.all())

    class Meta:
        verbose_name = _("Faq Question")

    def __unicode__(self):
        return f"Faq Question − {self.question}"

    def save(self, **kwargs):
        if self.slug == "":
            self.slug = slugify(self.question)
        super().save(**kwargs)


class Keyword(models.Model):
    keyword = models.CharField(_("Keyword"), max_length=100)

    def __unicode__(self):
        return f"{self.keyword}"

    def __str__(self):
        return f"{self.keyword}"


class SearchFaqPluginModel(CMSPlugin):
    name = models.CharField(_("Search name"), max_length=50)
    search_in = models.ManyToManyField(
        "djangocms_faq.FaqPluginModel",
        verbose_name=_("Search in"),
        limit_choices_to={"placeholder__page__publisher_is_draft": True},
        help_text=_("Format: name (source page name).<br />"),
    )
    uuid = models.UUIDField(primary_key=False, editable=False, default=uuid.uuid4)

    class Meta:
        verbose_name = _("Faq Search")

    def __unicode__(self):
        return f"Faq Search − {self.name}"

    def copy_relations(self, oldinstance):
        self.search_in.set(oldinstance.search_in.all())

        for faq in self.search_in.all():
            if not RelationSearchFaq.objects.filter(search=self.uuid, faq=faq.uuid):
                new_relation = RelationSearchFaq()
                new_relation.faq = (
                    self.uuid
                )  # should be faq.uuid but since it's already on many projects I'm leaving this as it is.
                new_relation.search = faq.uuid  # should be self.uuid but [...]
                new_relation.save()


class RelationSearchFaq(models.Model):
    faq = models.UUIDField(editable=False)
    search = models.UUIDField(editable=False)



import uuid

from cms.models.aliaspluginmodel import AliasPluginModel
from django.utils.text import slugify

from .settings import (
    ENABLE_FUZZY_SEARCH,
    FUZZY_SEARCH_PERCENTAGE,
    SEARCH_WORD_BY_WORD_KEYWORDS,
)


if ENABLE_FUZZY_SEARCH:
    try:
        # use fuzzy search, keep setting to True
        from thefuzz import fuzz
    except ImportError:
        # can't find package, set setting to False and print error
        print(
            "WARNING: Var DJANGOCMS_FAQ_ENABLE_FUZZY_SEARCH is set to True in your project's settings, but your installation of Python can't find the package thefuzz.\nHave you tried to install the package using \"python3 -m pip install djangocms_faq[fuzzy_search]\"?\nNot using fuzzy search for this time..."
        )
        ENABLE_FUZZY_SEARCH = False


from djangocms_faq.models import FaqPluginModel, QuestionFaqPluginModel


def get_answers(query, search_in, draft):

    if not len(query):
        return

    query = slugify(query)  # replace "AuJoürd'hui" by "aujourd-hui"

    if ENABLE_FUZZY_SEARCH:
        query = query.replace("-", " ")

    answers_questions = []
    answers_keywords = []

    uuid_list = [uuid.UUID(faq_uuid) for faq_uuid in search_in.split()]

    aliases = AliasPluginModel.objects.filter(plugin_type="FaqPluginPublisher")

    faq_list = [
        faq.id
        for faq in FaqPluginModel.objects.exclude(
            placeholder__page__publisher_is_draft=bool(draft)
        )
        .exclude(id__in=[alias.plugin_id for alias in aliases])
        .filter(uuid__in=uuid_list)
    ]
    # get questions
    questions = (
        QuestionFaqPluginModel.objects.exclude(
            placeholder__page__publisher_is_draft=bool(draft)
        )
        .exclude(placeholder__slot="clipboard")
        .filter(parent__id__in=faq_list)
    )

    # go through every question in list of selected FAQs
    for question in questions:

        # search in question title
        # fuzzy search = handle some user mistakes
        if ENABLE_FUZZY_SEARCH:
            question_str = slugify(question.question).replace("-", " ")

            # debug stuff:
            # print(query + " - " + question_str + " =>", end="")
            # print((30 - (len(query + " - " + question_str))) * " " + str(fuzz.token_sort_ratio(query, question_str)))

            # query is the slugified user query
            # question_str is the slugified question text
            if (
                fuzz.token_sort_ratio(query, question_str)
                >= FUZZY_SEARCH_PERCENTAGE  # see https://github.com/seatgeek/fuzzywuzzy#token-sort-ratio
            ) or (query in question_str):
                answers_questions.append(question)
        else:
            if query in slugify(question.question):
                answers_questions.append(question)

        # search in keywords
        for keyword in question.keywords.all():
            if ENABLE_FUZZY_SEARCH:
                keyword = slugify(keyword).replace("-", " ")
                # debug stuff
                # print("  " + query + " - " + keyword + " =>", end="")
                # print((30 - (len(query + " - " + keyword))) * " " + str(fuzz.token_sort_ratio(query, keyword)))

                # query is the slugified user query
                # keyword is the slugified keyword
                if fuzz.token_sort_ratio(query, keyword) >= FUZZY_SEARCH_PERCENTAGE:
                    answers_keywords.append(question)
            else:
                if query in slugify(keyword):
                    answers_keywords.append(question)

            # search correspondance word by word for each word in query and slugs
            if SEARCH_WORD_BY_WORD_KEYWORDS:
                query_list = query.split(" ")
                for query_word in query_list:
                    for keyword_word in keyword.keyword.split(" "):
                        if ENABLE_FUZZY_SEARCH:
                            if (
                                fuzz.token_sort_ratio(query_word, keyword_word)
                                >= FUZZY_SEARCH_PERCENTAGE
                            ):
                                answers_keywords.append(question)
                        else:
                            if query_word == keyword_word:
                                answers_keywords.append(question)

    # all answers
    answers = answers_questions + answers_keywords

    # get unique values
    answers = list(set(answers))

    return answers



from cms.admin.placeholderadmin import PlaceholderAdminMixin
from django.contrib import admin
from django.utils.safestring import mark_safe
from django.utils.translation import ugettext as _

from .models import FaqPluginModel, Keyword, QuestionFaqPluginModel


class DjangocmsFaqFaqPluginModel(PlaceholderAdminMixin, admin.ModelAdmin):
    list_display = ("name", "language", "get_page_url", "uuid")
    readonly_fields = ["uuid"]

    def get_queryset(self, request):
        qs = (
            super(DjangocmsFaqFaqPluginModel, self)
            .get_queryset(request)
            .exclude(placeholder__page__publisher_is_draft=False)
        )
        return qs

    def render_change_form(self, request, context, *args, **kwargs):
        self.change_form_template = "admin/change_form_help_text.html"
        extra = {
            "help_text": mark_safe(
                _(
                    "<i>Editing the faq using the django admin will only update the draft page, you will need to refresh the page to see the changes, and publish the page to made the changes appear on the live page.</i>"
                )
            )
        }
        context.update(extra)
        return super(DjangocmsFaqFaqPluginModel, self).render_change_form(
            request, context, *args, **kwargs
        )


class DjangocmsFaqQuestionFaqPluginModel(PlaceholderAdminMixin, admin.ModelAdmin):
    list_display = ("question", "language", "get_page_url", "id")
    autocomplete_fields = ("keywords",)

    def get_queryset(self, request):
        qs = (
            super(DjangocmsFaqQuestionFaqPluginModel, self)
            .get_queryset(request)
            .exclude(placeholder__page__publisher_is_draft=False)
        )
        return qs

    def render_change_form(self, request, context, *args, **kwargs):
        self.change_form_template = "admin/change_form_help_text.html"
        extra = {
            "help_text": mark_safe(
                _(
                    "<i>Editing a question using the django admin will only update the draft version, you will need to refresh the page to see the changes, and publish the page to made the changes appear on the live page.</i>"
                )
            )
        }
        context.update(extra)
        return super(DjangocmsFaqQuestionFaqPluginModel, self).render_change_form(
            request, context, *args, **kwargs
        )


class DjangocmsFaqKeywordAdmin(admin.ModelAdmin):

    list_display = ("id", "keyword")
    fieldsets = (("Add a keyword", {"fields": ("keyword",)}),)

    search_fields = ["question_text"]


admin.site.register(Keyword, DjangocmsFaqKeywordAdmin)
admin.site.register(QuestionFaqPluginModel, DjangocmsFaqQuestionFaqPluginModel)
admin.site.register(FaqPluginModel, DjangocmsFaqFaqPluginModel)



from django.conf import settings


ENABLE_API = getattr(settings, "DJANGOCMS_FAQ_ENABLE_API", True)

ANSWER_PLUGINS = getattr(
    settings,
    "DJANGOCMS_FAQ_ANSWER_PLUGINS",
    ["TextPlugin", "FilePlugin", "VideoPlayerPlugin"],
)

SHOW_KEYWORDS_QUESTION = getattr(settings, "DJANGOCMS_FAQ_SHOW_KEYWORDS_QUESTION", True)
SHOW_KEYWORDS_ANSWER = getattr(settings, "DJANGOCMS_FAQ_SHOW_KEYWORDS_ANSWER", True)

ENABLE_FUZZY_SEARCH = getattr(settings, "DJANGOCMS_FAQ_ENABLE_FUZZY_SEARCH", False)
FUZZY_SEARCH_PERCENTAGE = getattr(settings, "DJANGOCMS_FAQ_FUZZY_SEARCH_PERCENTAGE", 85)

SEARCH_WORD_BY_WORD_KEYWORDS = getattr(
    settings, "DJANGOCMS_FAQ_SEARCH_WORD_BY_WORD_KEYWORDS", False
)

MAX_QUERY_LENGTH = getattr(settings, "DJANGOCMS_FAQ_MAX_QUERY_LENGTH", 60)



from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool
from django.utils.translation import ugettext as _

from djangocms_faq.models import (
    FaqPluginModel,
    QuestionFaqPluginModel,
    SearchFaqPluginModel,
)

from .settings import (
    ANSWER_PLUGINS,
    ENABLE_API,
    MAX_QUERY_LENGTH,
    SHOW_KEYWORDS_ANSWER,
    SHOW_KEYWORDS_QUESTION,
)


@plugin_pool.register_plugin
class FaqPluginPublisher(CMSPluginBase):
    module = _("Faq")
    name = _("Faq Container")
    model = FaqPluginModel
    render_template = "faq/faq_plugin.html"
    allow_children = True
    child_classes = ["FaqPluginQuestionPublisher"]

    def render(self, context, instance, placeholder):
        context.update({"instance": instance})
        return context


@plugin_pool.register_plugin
class FaqPluginQuestionPublisher(CMSPluginBase):
    module = _("Faq")
    name = _("Faq Question")
    model = QuestionFaqPluginModel
    render_template = "faq/faq_question.html"
    allow_children = True
    child_classes = ANSWER_PLUGINS
    parent_classes = ["FaqPluginPublisher"]

    def render(self, context, instance, placeholder):
        context.update({"instance": instance})
        context.update({"show_keywords_question": SHOW_KEYWORDS_QUESTION})
        context.update({"show_keywords_answer": SHOW_KEYWORDS_ANSWER})
        return context


if ENABLE_API:

    from djangocms_faq.utils import get_answers

    @plugin_pool.register_plugin
    class FaqPluginSearchPublisher(CMSPluginBase):
        module = _("Faq")
        name = _("Faq Search")
        model = SearchFaqPluginModel
        render_template = "faq/faq_search.html"
        cache = False

        def render(self, context, instance, placeholder):
            context.update({"instance": instance})
            context.update({"show_keywords_question": SHOW_KEYWORDS_QUESTION})
            context.update({"show_keywords_answer": SHOW_KEYWORDS_ANSWER})

            if (
                "question" in context["request"].GET
                and len(context["request"].GET["question"]) > 2
            ):
                question = context["request"].GET["question"][:MAX_QUERY_LENGTH]

                if "search_in" in context["request"].GET:
                    search_in = context["request"].GET["search_in"]
                else:
                    search_in = ""

                draft = context["request"].GET.get("draft", False)

                context.update({"answers": get_answers(question, search_in, draft)})
            return context



from json import dumps

from django.http import HttpResponse

from djangocms_faq.utils import get_answers

from .settings import MAX_QUERY_LENGTH


def AnswerView(request):
    if "question" in request.GET and len(request.GET["question"]) > 2:
        question = request.GET["question"][:MAX_QUERY_LENGTH]

        if "search_in" in request.GET:
            search_in = request.GET["search_in"]
        else:
            search_in = ""

        draft = request.GET.get("draft", False)

        answers = get_answers(question, search_in, draft)

        jsondata = []

        if answers:
            for answer in answers:
                # look mom I'm creating ugly json!
                jsondata.append(
                    {
                        "question": answer.question,
                        "slug": answer.slug,
                        "url": answer.get_full_url,
                        "keywords": [
                            keyword.keyword for keyword in answer.keywords.all()
                        ],
                    }
                )

        return HttpResponse(dumps(jsondata), content_type="application/json")

    return HttpResponse("{}", content_type="application/json")



# Generated by Django 2.2 on 2021-04-06 16:10

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ("cms", "0022_auto_20180620_1551"),
    ]

    operations = [
        migrations.CreateModel(
            name="FaqPluginModel",
            fields=[
                (
                    "cmsplugin_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        related_name="djangocms_faq_faqpluginmodel",
                        serialize=False,
                        to="cms.CMSPlugin",
                    ),
                ),
                ("title", models.CharField(max_length=300, verbose_name="Titre")),
            ],
            options={
                "verbose_name": "Faq Container",
            },
            bases=("cms.cmsplugin",),
        ),
        migrations.CreateModel(
            name="Keyword",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("keyword", models.CharField(max_length=100, verbose_name="Keyword")),
            ],
        ),
        migrations.CreateModel(
            name="SearchFaqPluginModel",
            fields=[
                (
                    "cmsplugin_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        related_name="djangocms_faq_searchfaqpluginmodel",
                        serialize=False,
                        to="cms.CMSPlugin",
                    ),
                ),
                ("name", models.CharField(max_length=50, verbose_name="Search name")),
                (
                    "search_in",
                    models.ManyToManyField(
                        limit_choices_to={
                            "placeholder__page__publisher_is_draft": False
                        },
                        to="djangocms_faq.FaqPluginModel",
                        verbose_name="Search in",
                    ),
                ),
            ],
            options={
                "verbose_name": "Faq Search",
            },
            bases=("cms.cmsplugin",),
        ),
        migrations.CreateModel(
            name="QuestionFaqPluginModel",
            fields=[
                (
                    "cmsplugin_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        related_name="djangocms_faq_questionfaqpluginmodel",
                        serialize=False,
                        to="cms.CMSPlugin",
                    ),
                ),
                ("question", models.CharField(max_length=300, verbose_name="Question")),
                (
                    "slug",
                    models.SlugField(
                        blank=True,
                        default="",
                        help_text="Unique slug for this question. Keep empty to let it be auto-generated.",
                        max_length=300,
                    ),
                ),
                (
                    "keywords",
                    models.ManyToManyField(
                        to="djangocms_faq.Keyword", verbose_name="Keywords"
                    ),
                ),
            ],
            options={
                "verbose_name": "Faq Question",
            },
            bases=("cms.cmsplugin",),
        ),
    ]



# Generated by Django 2.2.23 on 2021-05-31 14:50

import uuid

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("djangocms_faq", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="RelationSearchFaq",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("faq", models.UUIDField(editable=False)),
                ("search", models.UUIDField(editable=False)),
            ],
        ),
        migrations.AlterModelOptions(
            name="faqpluginmodel",
            options={"verbose_name": "Conteneur de Faq"},
        ),
        migrations.AlterModelOptions(
            name="questionfaqpluginmodel",
            options={"verbose_name": "Question de Faq"},
        ),
        migrations.AlterModelOptions(
            name="searchfaqpluginmodel",
            options={"verbose_name": "Recherche Faq"},
        ),
        migrations.AddField(
            model_name="faqpluginmodel",
            name="show_title",
            field=models.BooleanField(default=True, verbose_name="Display title"),
        ),
        migrations.AddField(
            model_name="faqpluginmodel",
            name="uuid",
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AddField(
            model_name="searchfaqpluginmodel",
            name="uuid",
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AlterField(
            model_name="faqpluginmodel",
            name="title",
            field=models.CharField(blank=True, max_length=300, verbose_name="Titre"),
        ),
        migrations.AlterField(
            model_name="keyword",
            name="keyword",
            field=models.CharField(max_length=100, verbose_name="Mot-clef"),
        ),
        migrations.AlterField(
            model_name="questionfaqpluginmodel",
            name="keywords",
            field=models.ManyToManyField(
                to="djangocms_faq.Keyword", verbose_name="Mot-clefs"
            ),
        ),
        migrations.AlterField(
            model_name="questionfaqpluginmodel",
            name="slug",
            field=models.SlugField(
                blank=True,
                default="",
                help_text="Slug unique pour cette question. Laisser vide pour le laisse s'auto-générer.",
                max_length=300,
            ),
        ),
        migrations.AlterField(
            model_name="searchfaqpluginmodel",
            name="name",
            field=models.CharField(max_length=50, verbose_name="Nom de la recherche"),
        ),
        migrations.AlterField(
            model_name="searchfaqpluginmodel",
            name="search_in",
            field=models.ManyToManyField(
                limit_choices_to={"placeholder__page__publisher_is_draft": False},
                to="djangocms_faq.FaqPluginModel",
                verbose_name="Rechercher dans",
            ),
        ),
    ]
